==> baseui-6.0.0.tgz: package/esm/datepicker/day.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { StyledDay } from './styled-components.js';
import { getDay, getMonth, getDate, isSameDay, isDayInRange, isAfter } from './utils/index.js';
import { getOverrides } from '../helpers/overrides.js';

var Day =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Day, _React$Component);

  function Day() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Day);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Day)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      isHovered: false
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onKeyDown", function (event) {
      var _this$props = _this.props,
          isHighlighted = _this$props.isHighlighted,
          date = _this$props.date,
          disabled = _this$props.disabled;

      if (event.key === 'Enter' && isHighlighted && !disabled) {
        event.preventDefault();

        _this.onSelect(date);
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onClick", function (event) {
      var _this$props2 = _this.props,
          date = _this$props2.date,
          disabled = _this$props2.disabled;

      if (!disabled) {
        _this.props.onClick({
          event: event,
          date: date
        });

        _this.onSelect(date);
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onMouseOver", function (event) {
      _this.setState({
        isHovered: true
      });

      _this.props.onMouseOver({
        event: event,
        date: _this.props.date
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onMouseLeave", function (event) {
      _this.setState({
        isHovered: false
      });

      _this.props.onMouseLeave({
        event: event,
        date: _this.props.date
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "isWeekend", function () {
      var weekday = getDay(_this.props.date);
      return weekday === 0 || weekday === 6;
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "isOutsideMonth", function () {
      return _this.props.month !== undefined && _this.props.month !== getMonth(_this.props.date);
    });

    return _this;
  }

  _createClass(Day, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.addEventListener('keydown', this.onKeyDown);
        }
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      if (this.props.isHighlighted && this.props.isHighlighted !== prevProps.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.addEventListener('keydown', this.onKeyDown);
        }
      } else if (!this.props.isHighlighted && this.props.isHighlighted !== prevProps.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.removeEventListener('keydown', this.onKeyDown);
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (typeof document !== 'undefined') {
        document.removeEventListener('keydown', this.onKeyDown);
      }
    }
  }, {
    key: "onSelect",
    value: function onSelect(selectedDate) {
      var _this$props3 = this.props,
          isRange = _this$props3.isRange,
          value = _this$props3.value;
      var date;

      if (Array.isArray(value) && isRange) {
        if (!value.length || value.length > 1) {
          date = [selectedDate];
        } else if (isAfter(selectedDate, value[0])) {
          date = [value[0], selectedDate];
        } else {
          date = [selectedDate, value[0]];
        }
      } else {
        date = selectedDate;
      }

      this.props.onSelect({
        date: date
      });
    }
  }, {
    key: "isSelected",
    value: function isSelected() {
      var _this$props4 = this.props,
          value = _this$props4.value,
          date = _this$props4.date;

      if (Array.isArray(value)) {
        return isSameDay(date, value[0]) || isSameDay(date, value[1]);
      } else {
        return isSameDay(date, value);
      }
    } // calculated for range case only

  }, {
    key: "isPseudoSelected",
    value: function isPseudoSelected() {
      var _this$props5 = this.props,
          date = _this$props5.date,
          value = _this$props5.value; // fix flow by passing a specific arg type and remove 'Array.isArray(value)'

      if (Array.isArray(value) && value.length > 1) {
        return isDayInRange(date, value[0], value[1]);
      }
    } // calculated for range case only

  }, {
    key: "isPseudoHighlighted",
    value: function isPseudoHighlighted() {
      var _this$props6 = this.props,
          date = _this$props6.date,
          value = _this$props6.value,
          highlightedDate = _this$props6.highlightedDate; // fix flow by passing a specific arg type and remove 'Array.isArray(value)'

      if (Array.isArray(value) && highlightedDate && value[0] && !value[1]) {
        if (isAfter(highlightedDate, value[0])) {
          return isDayInRange(date, value[0], highlightedDate);
        } else {
          return isDayInRange(date, highlightedDate, value[0]);
        }
      }
    }
  }, {
    key: "getSharedProps",
    value: function getSharedProps() {
      var _this$props7 = this.props,
          date = _this$props7.date,
          value = _this$props7.value,
          highlightedDate = _this$props7.highlightedDate,
          isRange = _this$props7.isRange,
          isHighlighted = _this$props7.isHighlighted;
      var $isHighlighted = isHighlighted;
      var $selected = this.isSelected();
      var $hasRangeHighlighted = Array.isArray(value) && isRange && value.length === 1 && highlightedDate && !isSameDay(value[0], highlightedDate) ? true : false;
      return {
        $date: date,
        $disabled: this.props.disabled,
        $endDate: Array.isArray(value) && this.props.isRange && $selected && isSameDay(date, value[1]) || false,
        $isHovered: this.state.isHovered,
        $isHighlighted: $isHighlighted,
        $isRange: this.props.isRange,
        $hasRangeHighlighted: $hasRangeHighlighted,
        $hasRangeOnRight: Array.isArray(value) && $hasRangeHighlighted && highlightedDate && value[0] && isAfter(highlightedDate, value[0]),
        $hasRangeSelected: Array.isArray(value) ? value.length === 2 : false,
        $highlightedDate: highlightedDate,
        $peekNextMonth: this.props.peekNextMonth,
        $pseudoHighlighted: this.props.isRange && !$isHighlighted && !$selected ? this.isPseudoHighlighted() : false,
        $pseudoSelected: this.props.isRange && !$selected ? this.isPseudoSelected() : false,
        $selected: $selected,
        $startDate: Array.isArray(this.props.value) && this.props.isRange && $selected ? isSameDay(date, this.props.value[0]) : false,
        $outsideMonth: this.isOutsideMonth()
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props8 = this.props,
          date = _this$props8.date,
          peekNextMonth = _this$props8.peekNextMonth,
          _this$props8$override = _this$props8.overrides,
          overrides = _this$props8$override === void 0 ? {} : _this$props8$override;
      var sharedProps = this.getSharedProps();

      var _getOverrides = getOverrides(overrides.Day, StyledDay),
          _getOverrides2 = _slicedToArray(_getOverrides, 2),
          Day = _getOverrides2[0],
          dayProps = _getOverrides2[1];

      return !peekNextMonth && sharedProps.$outsideMonth ? React.createElement(Day, null) : // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
      React.createElement(Day, _extends({
        "aria-label": "day-".concat(getDate(date)),
        role: "option"
      }, sharedProps, dayProps, {
        // Adding event handlers after customers overrides in order to
        // make sure the components functions as expected
        // We can extract the handlers from props overrides
        // and call it along with internal handlers by creating an inline handler
        onClick: this.onClick,
        onMouseOver: this.onMouseOver,
        onMouseLeave: this.onMouseLeave
      }), getDate(date));
    }
  }]);

  return Day;
}(React.Component);

_defineProperty(Day, "defaultProps", {
  disabled: false,
  date: new Date(),
  isHighlighted: false,
  isRange: false,
  month: new Date().getMonth(),
  onClick: function onClick() {},
  onSelect: function onSelect() {},
  onMouseOver: function onMouseOver() {},
  onMouseLeave: function onMouseLeave() {},
  overrides: {},
  peekNextMonth: true,
  value: null
});

export { Day as default };

==> baseui-6.0.1.tgz: package/esm/datepicker/day.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { StyledDay } from './styled-components.js';
import { formatDate, getDay, getMonth, getDate, isSameDay, isDayInRange, isAfter } from './utils/index.js';
import { getOverrides } from '../helpers/overrides.js';

var Day =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Day, _React$Component);

  function Day() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Day);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Day)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      isHovered: false
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onKeyDown", function (event) {
      var _this$props = _this.props,
          isHighlighted = _this$props.isHighlighted,
          date = _this$props.date,
          disabled = _this$props.disabled;

      if (event.key === 'Enter' && isHighlighted && !disabled) {
        event.preventDefault();

        _this.onSelect(date);
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onClick", function (event) {
      var _this$props2 = _this.props,
          date = _this$props2.date,
          disabled = _this$props2.disabled;

      if (!disabled) {
        _this.props.onClick({
          event: event,
          date: date
        });

        _this.onSelect(date);
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onMouseOver", function (event) {
      _this.setState({
        isHovered: true
      });

      _this.props.onMouseOver({
        event: event,
        date: _this.props.date
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onMouseLeave", function (event) {
      _this.setState({
        isHovered: false
      });

      _this.props.onMouseLeave({
        event: event,
        date: _this.props.date
      });
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "isWeekend", function () {
      var weekday = getDay(_this.props.date);
      return weekday === 0 || weekday === 6;
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "isOutsideMonth", function () {
      return _this.props.month !== undefined && _this.props.month !== getMonth(_this.props.date);
    });

    return _this;
  }

  _createClass(Day, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.addEventListener('keydown', this.onKeyDown);
        }
      }
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      if (this.props.isHighlighted && this.props.isHighlighted !== prevProps.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.addEventListener('keydown', this.onKeyDown);
        }
      } else if (!this.props.isHighlighted && this.props.isHighlighted !== prevProps.isHighlighted) {
        if (typeof document !== 'undefined') {
          document.removeEventListener('keydown', this.onKeyDown);
        }
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (typeof document !== 'undefined') {
        document.removeEventListener('keydown', this.onKeyDown);
      }
    }
  }, {
    key: "onSelect",
    value: function onSelect(selectedDate) {
      var _this$props3 = this.props,
          isRange = _this$props3.isRange,
          value = _this$props3.value;
      var date;

      if (Array.isArray(value) && isRange) {
        if (!value.length || value.length > 1) {
          date = [selectedDate];
        } else if (isAfter(selectedDate, value[0])) {
          date = [value[0], selectedDate];
        } else {
          date = [selectedDate, value[0]];
        }
      } else {
        date = selectedDate;
      }

      this.props.onSelect({
        date: date
      });
    }
  }, {
    key: "isSelected",
    value: function isSelected() {
      var _this$props4 = this.props,
          value = _this$props4.value,
          date = _this$props4.date;

      if (Array.isArray(value)) {
        return isSameDay(date, value[0]) || isSameDay(date, value[1]);
      } else {
        return isSameDay(date, value);
      }
    } // calculated for range case only

  }, {
    key: "isPseudoSelected",
    value: function isPseudoSelected() {
      var _this$props5 = this.props,
          date = _this$props5.date,
          value = _this$props5.value; // fix flow by passing a specific arg type and remove 'Array.isArray(value)'

      if (Array.isArray(value) && value.length > 1) {
        return isDayInRange(date, value[0], value[1]);
      }
    } // calculated for range case only

  }, {
    key: "isPseudoHighlighted",
    value: function isPseudoHighlighted() {
      var _this$props6 = this.props,
          date = _this$props6.date,
          value = _this$props6.value,
          highlightedDate = _this$props6.highlightedDate; // fix flow by passing a specific arg type and remove 'Array.isArray(value)'

      if (Array.isArray(value) && highlightedDate && value[0] && !value[1]) {
        if (isAfter(highlightedDate, value[0])) {
          return isDayInRange(date, value[0], highlightedDate);
        } else {
          return isDayInRange(date, highlightedDate, value[0]);
        }
      }
    }
  }, {
    key: "getSharedProps",
    value: function getSharedProps() {
      var _this$props7 = this.props,
          date = _this$props7.date,
          value = _this$props7.value,
          highlightedDate = _this$props7.highlightedDate,
          isRange = _this$props7.isRange,
          isHighlighted = _this$props7.isHighlighted;
      var $isHighlighted = isHighlighted;
      var $selected = this.isSelected();
      var $hasRangeHighlighted = Array.isArray(value) && isRange && value.length === 1 && highlightedDate && !isSameDay(value[0], highlightedDate) ? true : false;
      return {
        $date: date,
        $disabled: this.props.disabled,
        $endDate: Array.isArray(value) && this.props.isRange && $selected && isSameDay(date, value[1]) || false,
        $isHovered: this.state.isHovered,
        $isHighlighted: $isHighlighted,
        $isRange: this.props.isRange,
        $hasRangeHighlighted: $hasRangeHighlighted,
        $hasRangeOnRight: Array.isArray(value) && $hasRangeHighlighted && highlightedDate && value[0] && isAfter(highlightedDate, value[0]),
        $hasRangeSelected: Array.isArray(value) ? value.length === 2 : false,
        $highlightedDate: highlightedDate,
        $peekNextMonth: this.props.peekNextMonth,
        $pseudoHighlighted: this.props.isRange && !$isHighlighted && !$selected ? this.isPseudoHighlighted() : false,
        $pseudoSelected: this.props.isRange && !$selected ? this.isPseudoSelected() : false,
        $selected: $selected,
        $startDate: Array.isArray(this.props.value) && this.props.isRange && $selected ? isSameDay(date, this.props.value[0]) : false,
        $outsideMonth: this.isOutsideMonth()
      };
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props8 = this.props,
          date = _this$props8.date,
          peekNextMonth = _this$props8.peekNextMonth,
          _this$props8$override = _this$props8.overrides,
          overrides = _this$props8$override === void 0 ? {} : _this$props8$override;
      var sharedProps = this.getSharedProps();

      var _getOverrides = getOverrides(overrides.Day, StyledDay),
          _getOverrides2 = _slicedToArray(_getOverrides, 2),
          Day = _getOverrides2[0],
          dayProps = _getOverrides2[1];

      return !peekNextMonth && sharedProps.$outsideMonth ? React.createElement(Day, null) : // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
      React.createElement(Day, _extends({
        "aria-label": formatDate(date, 'EEEE, MMMM do YYYY', this.props.locale),
        role: "cell"
      }, sharedProps, dayProps, {
        // Adding event handlers after customers overrides in order to
        // make sure the components functions as expected
        // We can extract the handlers from props overrides
        // and call it along with internal handlers by creating an inline handler
        onClick: this.onClick,
        onMouseOver: this.onMouseOver,
        onMouseLeave: this.onMouseLeave
      }), getDate(date));
    }
  }]);

  return Day;
}(React.Component);

_defineProperty(Day, "defaultProps", {
  disabled: false,
  date: new Date(),
  isHighlighted: false,
  isRange: false,
  month: new Date().getMonth(),
  onClick: function onClick() {},
  onSelect: function onSelect() {},
  onMouseOver: function onMouseOver() {},
  onMouseLeave: function onMouseLeave() {},
  overrides: {},
  peekNextMonth: true,
  value: null
});

export { Day as default };
